@@ -63,6 +63,9 @@ knowledge of the CeCILL-C or CeCILL license and that you accept its terms.
 #if HAVE_STRING_H
 #include <string.h>
 #endif
+#if HAVE_STRINGS_H
+#include <strings.h>
+#endif
 #define __SCSCP_WITHIN_SCSCP
 #include "scscp.h"
 #include "scscpinternal.h"
@@ -215,7 +218,7 @@ static SCSCP_omnodeptr SCSCP_omdoc_allocatenode(SCSCP_omdocptr doc)
 /*-----------------------------------------------------------------*/
 static void* SCSCP_omdoc_allocateinnode(SCSCP_omdocptr doc, size_t len)
 {
- void *data;
+ void *data = NULL;
  SCSCP_debugprint("SCSCP_omdoc_allocateinnode(%p,%lu) - enter\n", doc, (unsigned long) len);
  len = (len+sizeof(void*)-1)&(~(sizeof(void*)-1));
  if (doc->m_nodes==NULL || doc->m_Writepos_nodes+len>=doc->m_nodes->m_len)
